@@ -21,6 +21,9 @@
 #include <assert.h>
 #include <xplc/xplc.h>
 
+// N_() is defined here just for internationalization.
+#define N_(String)  String
+
 static char *	init_responses[] = {
 	"ok",
 	"error",
@@ -246,7 +249,7 @@ void WvDialer::hangup()
     }
 }
 
-bool WvDialer::pre_select( SelectInfo& si )
+void WvDialer::pre_select( SelectInfo& si )
 /*******************************************/
 {
     if( isok() && stat != Online && stat != Idle
@@ -256,14 +259,33 @@ bool WvDialer::pre_select( SelectInfo& si )
 	// select() already returns true whenever the modem is readable,
 	// but when we are doing a timeout (eg. PreDial1/2) for example,
 	// we need to execute() even if no modem data is incoming.
-	return( true );
+	si.msec_timeout = 0;
     } 
     else 
     {
-	return WvStreamClone::pre_select( si );
+	WvStreamClone::pre_select( si );
     }
 }
 
+
+bool WvDialer::post_select( SelectInfo& si )
+{
+    if( isok() && stat != Online && stat != Idle
+	&& time( NULL ) - last_execute > 1 )
+    {
+	// Pretend we have "data ready," so execute() gets called.
+	// select() already returns true whenever the modem is readable,
+	// but when we are doing a timeout (eg. PreDial1/2) for example,
+	// we need to execute() even if no modem data is incoming.
+	return true;
+    } 
+    else 
+    {
+	return WvStreamClone::post_select( si );
+    }
+}
+
+
 bool WvDialer::isok() const
 /*************************/
 {
@@ -288,27 +310,27 @@ char *WvDialer::connect_status() const
     case Dial:
     case WaitDial:
 	if( dial_stat == 1 )
-	    strcpy( msg, "Last attempt timed out.  Trying again." );
+	    strcpy( msg, N_("Last attempt timed out.  Trying again.") );
 	else if( dial_stat == 2 )
-	    strcpy( msg, "Modem did not connect last attempt.  Trying again." );
+	    strcpy( msg, N_("Modem did not connect last attempt.  Trying again.") );
 	else if( dial_stat == 3 )
-	    strcpy( msg, "No dial tone last attempt.  Trying again." );
+	    strcpy( msg, N_("No dial tone last attempt.  Trying again.") );
     	else if( dial_stat == 4 )
-    	    strcpy( msg, "Busy signal on last attempt.  Trying again." );
+    	    strcpy( msg, N_("Busy signal on last attempt.  Trying again.") );
     	else if( dial_stat == 5 )
-    	    strcpy( msg, "Voice answer on last attempt.  Trying again." );
+    	    strcpy( msg, N_("Voice answer on last attempt.  Trying again.") );
     	else if( dial_stat == 6 )
-    	    strcpy( msg, "Fax answer on last attempt.  Trying again." );
+    	    strcpy( msg, N_("Fax answer on last attempt.  Trying again.") );
 	else if( dial_stat == 7 )
-            strcpy( msg, "No answer on last attempt.  Trying again." );
+            strcpy( msg, N_("No answer on last attempt.  Trying again.") );
     	else
     	    return( NULL );
 	break;
     case WaitAnything:
-    	strcpy( msg, "Waiting for a response from Internet Provider." );
+    	strcpy( msg, N_("Waiting for a response from Internet Provider.") );
     	break;
     case WaitPrompt:
-    	strcpy( msg, "Waiting for a prompt from Internet Provider." );
+    	strcpy( msg, N_("Waiting for a prompt from Internet Provider.") );
     	break;
     case AutoReconnectDelay:
     	sprintf( msg, "Next attempt in 00:%02ld:%02ld.", 
