@@ -1,6 +1,6 @@
 /*
  * Worldvisions Weaver Software:
- *   Copyright (C) 1997-2002 Net Integration Technologies, Inc.
+ *   Copyright (C) 1997-2003 Net Integration Technologies, Inc.
  *
  * Re-write of wvpapsecrets.h.  This one supports CHAP as well, and is also
  * much safer.
@@ -9,7 +9,7 @@
 #ifndef __WVPAPCHAP_H
 #define __WVPAPCHAP_H
 
-#include "wvconf.h"
+#include "wvconfemu.h"
 #include "wvlinklist.h"
 #include "wvstring.h"
 
